@@ -6,6 +6,7 @@ export const defaultLocale = 'en-US'
 
 export const supportedLocales = [
   defaultLocale,
+  'cs-CZ',
   'de-DE',
   'es-ES',
   'fr-FR',
@@ -30,9 +31,19 @@ export const searchPrefixes = {
   cluster: 'Cluster',
   host: 'Host',
   storage: 'Storage',
-  vm: 'Vm',
-  event: 'Event',
-  volume: 'Volume'
+  vm: 'Vms',
+  event: 'Events',
+  volume: 'Volumes'
+}
+
+export const webadminPlaces = {
+  dc: 'dataCenters',
+  cluster: 'clusters',
+  host: 'hosts',
+  storage: 'storage',
+  vm: 'vms',
+  event: 'events',
+  volume: 'volumes'
 }
 
 export const searchFields = {
